@@ -27,11 +27,11 @@ class IntegrateAssistant : public Cantor::Assistant
 {
   public:
     IntegrateAssistant( QObject* parent, QList<QVariant> args );
-    ~IntegrateAssistant() override;
+    ~IntegrateAssistant() override = default;
 
-    void initActions() Q_DECL_OVERRIDE;
+    void initActions() override;
     
-    QStringList run(QWidget* parentt) Q_DECL_OVERRIDE;
+    QStringList run(QWidget* parentt) override;
     
 };
 
