@@ -28,10 +28,10 @@ class Plot2dAssistant : public Cantor::Assistant
   Q_OBJECT
   public:
     Plot2dAssistant( QObject* parent, QList<QVariant> args );
-    ~Plot2dAssistant() override;
+    ~Plot2dAssistant() override = default;
 
-    void initActions() Q_DECL_OVERRIDE;
-    QStringList run(QWidget* parentt) Q_DECL_OVERRIDE;
+    void initActions() override;
+    QStringList run(QWidget* parentt) override;
 };
 
 #endif /* _PLOT2DASSISTANT_H */
