@@ -27,11 +27,11 @@ class SolveAssistant : public Cantor::Assistant
 {
   public:
     SolveAssistant( QObject* parent, QList<QVariant> args );
-    ~SolveAssistant() override;
+    ~SolveAssistant() override = default;
 
-    void initActions() Q_DECL_OVERRIDE;
+    void initActions() override;
     
-    QStringList run(QWidget* parentt) Q_DECL_OVERRIDE;
+    QStringList run(QWidget* parentt) override;
     
 };
 
