@@ -31,6 +31,7 @@
 #include <QDebug>
 #include <QProcess>
 #include <QTimer>
+#include <QStandardPaths>
 
 #include <KMessageBox>
 #include <KLocalizedString>
@@ -106,27 +107,21 @@ void MaximaSession::logout()
 
     disconnect(m_process, nullptr, this, nullptr);
 
-//     if(status()==Cantor::Session::Running)
-        //TODO: terminate the running expressions first
+    if (status() == Cantor::Session::Running)
+        interrupt();
 
     write(QLatin1String("quit();\n"));
     qDebug()<<"waiting for maxima to finish";
-    m_process->waitForFinished();
-    qDebug()<<"maxima exit finished";
 
-    if(m_process->state() != QProcess::NotRunning)
+    if(!m_process->waitForFinished(1000))
     {
         m_process->kill();
         qDebug()<<"maxima still running, process kill enforced";
     }
-
-    expressionQueue().clear();
-    delete m_process;
+    m_process->deleteLater();
     m_process = nullptr;
-    variableModel()->clearVariables();
-    variableModel()->clearFunctions();
 
-    changeStatus(Status::Disable);
+    Session::logout();
 
     qDebug()<<"logout done";
 }
@@ -245,7 +240,7 @@ void MaximaSession::interrupt()
     if(!expressionQueue().isEmpty())
     {
         qDebug()<<"interrupting " << expressionQueue().first()->command();
-        if(m_process->state() != QProcess::NotRunning)
+        if(m_process && m_process->state() != QProcess::NotRunning)
         {
 #ifndef Q_OS_WIN
             const int pid=m_process->pid();
