@@ -26,7 +26,6 @@
 #include "textresult.h"
 
 #include "settings.h"
-#include "octavehighlighter.h"
 
 #include <KProcess>
 #include <KDirWatch>
@@ -287,7 +286,7 @@ void OctaveSession::readOutput()
             // octave print subprompt and waits input finish.
             m_syntaxError = true;
             qDebug() << "subprompt catch";
-            m_process->write(")]'\"\n"); // forse exit from subprompt
+            m_process->write(")]'\"\n"); // force exit from subprompt
             m_output.clear();
         }
         else
