@@ -26,8 +26,10 @@
 #include "result.h"
 #include "imageresult.h"
 #include "textresult.h"
+#include "helpresult.h"
 #include "epsresult.h"
 #include "completionobject.h"
+#include "syntaxhelpobject.h"
 #include "defaultvariablemodel.h"
 
 #include "octaveexpression.h"
@@ -264,5 +266,56 @@ void TestOctave::testInvalidSyntax()
     QCOMPARE( e->status(), Cantor::Expression::Error );
 }
 
+void TestOctave::testHelpRequest()
+{
+    Cantor::Expression* e = evalExp(QLatin1String("help printf"));
+
+    QVERIFY(e != nullptr);
+    QCOMPARE(e->status(), Cantor::Expression::Status::Done);
+    QVERIFY(e->result() != nullptr);
+    QCOMPARE(e->result()->type(), (int)Cantor::HelpResult::Type);
+    QString text = QString::fromLatin1("Print optional arguments under the control of the template").toHtmlEscaped();
+    text.replace(QLatin1Char(' '), QLatin1String("&nbsp;"));
+    QVERIFY(e->result()->toHtml().contains(text));
+}
+
+void TestOctave::testSyntaxHelp()
+{
+    Cantor::SyntaxHelpObject* help = session()->syntaxHelpFor(QLatin1String("abs"));
+    help->fetchSyntaxHelp();
+    waitForSignal(help, SIGNAL(done()));
+
+    QString text = QString::fromLatin1("Compute the magnitude").toHtmlEscaped();
+    text.replace(QLatin1Char(' '), QLatin1String("&nbsp;"));
+    QVERIFY(help->toHtml().contains(text));
+}
+
+void TestOctave::testLoginLogout()
+{
+    // Logout from session twice and all must works fine
+    session()->logout();
+    session()->logout();
+
+    // Login in session twice and all must works fine
+    session()->login();
+    session()->login();
+}
+
+void TestOctave::testRestartWhileRunning()
+{
+    Cantor::Expression* e1=session()->evaluateExpression(QLatin1String("sleep(5)"));
+
+    session()->logout();
+    QCOMPARE(e1->status(), Cantor::Expression::Interrupted);
+    session()->login();
+
+    Cantor::Expression* e2=evalExp( QLatin1String("2+2") );
+
+    QVERIFY(e2 != nullptr);
+    QVERIFY(e2->result() != nullptr);
+
+    QCOMPARE(cleanOutput(e2->result()->data().toString() ), QLatin1String("ans =  4"));
+}
+
 QTEST_MAIN( TestOctave )
 
