@@ -19,23 +19,20 @@
  */
 
 #include "pythonserver.h"
+#include <vector>
 
-#include <QFileInfo>
-#include <QDir>
 #include <Python.h>
 
-PythonServer::PythonServer(QObject* parent) : QObject(parent), m_pModule(nullptr)
-{
-}
+using namespace std;
 
 namespace
 {
-    QString pyObjectToQString(PyObject* obj)
+    string pyObjectToQString(PyObject* obj)
     {
 #if PY_MAJOR_VERSION == 3
-        return QString::fromUtf8(PyUnicode_AsUTF8(obj));
+        return string(PyUnicode_AsUTF8(obj));
 #elif PY_MAJOR_VERSION == 2
-        return QString::fromLocal8Bit(PyString_AsString(obj));
+        return string(PyString_AsString(obj));
 #else
     #warning Unknown Python version
 #endif
@@ -47,12 +44,18 @@ void PythonServer::login()
     Py_InspectFlag = 1;
     Py_Initialize();
     m_pModule = PyImport_AddModule("__main__");
-    filePath = QStringLiteral("python_cantor_worksheet");
+    filePath = "python_cantor_worksheet";
 }
 
-void PythonServer::runPythonCommand(const QString& command) const
+void PythonServer::interrupt()
+{
+    PyErr_SetInterrupt();
+}
+
+void PythonServer::runPythonCommand(const string& command)
 {
     PyObject* py_dict = PyModule_GetDict(m_pModule);
+    m_error = false;
 
     const char* prepareCommand =
         "import sys;\n"\
@@ -68,7 +71,7 @@ void PythonServer::runPythonCommand(const QString& command) const
     PyRun_SimpleString(prepareCommand);
 
 #if PY_MAJOR_VERSION == 3
-    PyObject* compile = Py_CompileString(command.toStdString().c_str(), filePath.toStdString().c_str(), Py_single_input);
+    PyObject* compile = Py_CompileString(command.c_str(), filePath.c_str(), Py_single_input);
     // There are two reasons for the error:
     // 1) This code is not single expression, so we can't compile this with flag Py_single_input
     // 2) There are errors in the code
@@ -76,10 +79,11 @@ void PythonServer::runPythonCommand(const QString& command) const
     {
         PyErr_Clear();
         // Try to recompile code as sequence of expressions
-        compile = Py_CompileString(command.toStdString().c_str(), filePath.toStdString().c_str(), Py_file_input);
+        compile = Py_CompileString(command.c_str(), filePath.c_str(), Py_file_input);
         if (PyErr_Occurred())
         {
             // We now know, that we have a syntax error, so print the traceback and exit
+            m_error = true;
             PyErr_PrintEx(0);
             return;
         }
@@ -89,13 +93,14 @@ void PythonServer::runPythonCommand(const QString& command) const
     // Python 2.X don't check, that input string contains only one expression.
     // So for checking this, we compile string as file and as single expression and compare bytecode
     // FIXME?
-    PyObject* codeFile = Py_CompileString(command.toStdString().c_str(), filePath.toStdString().c_str(), Py_file_input);
+    PyObject* codeFile = Py_CompileString(command.c_str(), filePath.c_str(), Py_file_input);
     if (PyErr_Occurred())
     {
+        m_error = true;
         PyErr_PrintEx(0);
         return;
     }
-    PyObject* codeSingle = Py_CompileString(command.toStdString().c_str(), filePath.toStdString().c_str(), Py_single_input);
+    PyObject* codeSingle = Py_CompileString(command.c_str(), filePath.c_str(), Py_single_input);
     if (PyErr_Occurred())
     {
         // We have error with Py_single_input, but haven't error with Py_file_input
@@ -121,10 +126,13 @@ void PythonServer::runPythonCommand(const QString& command) const
     #warning Unknown Python version
 #endif
     if (PyErr_Occurred())
+    {
+        m_error = true;
         PyErr_PrintEx(0);
+    }
 }
 
-QString PythonServer::getError() const
+string PythonServer::getError() const
 {
     PyObject *errorPython = PyObject_GetAttrString(m_pModule, "errorPythonBackend");
     PyObject *error = PyObject_GetAttrString(errorPython, "value");
@@ -132,7 +140,7 @@ QString PythonServer::getError() const
     return pyObjectToQString(error);
 }
 
-QString PythonServer::getOutput() const
+string PythonServer::getOutput() const
 {
     PyObject *outputPython = PyObject_GetAttrString(m_pModule, "outputPythonBackend");
     PyObject *output = PyObject_GetAttrString(outputPython, "value");
@@ -140,51 +148,50 @@ QString PythonServer::getOutput() const
     return pyObjectToQString(output);
 }
 
-void PythonServer::setFilePath(const QString& path)
+void PythonServer::setFilePath(const string& path, const string& dir)
 {
-    this->filePath = path;
-    PyRun_SimpleString(("import sys; sys.argv = ['" + path.toStdString() + "']").c_str());
-    QString dir = QFileInfo(path).absoluteDir().absolutePath();
-    PyRun_SimpleString(("import sys; sys.path.insert(0, '" + dir.toStdString() + "')").c_str());
-    PyRun_SimpleString(("__file__ = '"+path.toStdString()+"'").c_str());
+    PyRun_SimpleString(("import sys; sys.argv = ['" + path + "']").c_str());
+    if (path.length() == 0) // New session, not from file
+    {
+        PyRun_SimpleString("import sys; sys.path.insert(0, '')");
+    }
+    else
+    {
+        this->filePath = path;
+        PyRun_SimpleString(("import sys; sys.path.insert(0, '" + dir + "')").c_str());
+        PyRun_SimpleString(("__file__ = '"+path+"'").c_str());
+    }
 }
 
-QString PythonServer::variables(bool parseValue) const
+string PythonServer::variables(bool parseValue) const
 {
-    // FIXME: This code allows get full form of numpy array, but for big arrays it's could cause performonce problems
-    // especially for displaying in variables panel
-    // So, uncomment this, when fix this problem
-    /*
+    PyRun_SimpleString(
         "try: \n"
         "   import numpy \n"
         "   __cantor_numpy_internal__ = numpy.get_printoptions()['threshold'] \n"
         "   numpy.set_printoptions(threshold=100000000) \n"
+#if PY_MAJOR_VERSION == 3
         "except ModuleNotFoundError: \n"
+#elif PY_MAJOR_VERSION == 2
+        "except ImportError: \n"
+#endif
         "   pass \n"
-
-        "try: \n"
-        "   import numpy \n"
-        "   numpy.set_printoptions(threshold=__cantor_numpy_internal__) \n"
-        "   del __cantor_numpy_internal__ \n"
-        "except ModuleNotFoundError: \n"
-        "   pass \n"
-    */
+    );
 
     PyRun_SimpleString("__tmp_globals__ = globals()");
     PyObject* globals = PyObject_GetAttrString(m_pModule,"__tmp_globals__");
     PyObject *key, *value;
     Py_ssize_t pos = 0;
 
-    QStringList vars;
-    const QChar sep(30); // INFORMATION SEPARATOR TWO
+    vector<string> vars;
     while (PyDict_Next(globals, &pos, &key, &value)) {
-        const QString& keyString = pyObjectToQString(key);
-        if (keyString.startsWith(QLatin1String("__")))
+        const string& keyString = pyObjectToQString(key);
+        if (keyString.substr(0, 2) == string("__"))
             continue;
 
-        if (keyString == QLatin1String("CatchOutPythonBackend")
-            || keyString == QLatin1String("errorPythonBackend")
-            || keyString == QLatin1String("outputPythonBackend"))
+        if (keyString == string("CatchOutPythonBackend")
+            || keyString == string("errorPythonBackend")
+            || keyString == string("outputPythonBackend"))
             continue;
 
         if (PyModule_Check(value))
@@ -196,15 +203,37 @@ QString PythonServer::variables(bool parseValue) const
         if (PyType_Check(value))
             continue;
 
-        QString valueString;
+        string valueString;
         if (parseValue)
             valueString = pyObjectToQString(PyObject_Repr(value));
 
-
-        vars.append(keyString + QChar(31) + valueString);
+        vars.push_back(keyString + char(17) + valueString);
     }
 
-    return vars.join(sep);
+    PyRun_SimpleString(
+        "try: \n"
+        "   import numpy \n"
+        "   numpy.set_printoptions(threshold=__cantor_numpy_internal__) \n"
+        "   del __cantor_numpy_internal__ \n"
+#if PY_MAJOR_VERSION == 3
+        "except ModuleNotFoundError: \n"
+#elif PY_MAJOR_VERSION == 2
+        "except ImportError: \n"
+#endif
+        "   pass \n"
+    );
+
+
+    string result;
+    for (const string& s : vars)
+        result += s + char(18);
+    result += char(18);
+    return result;
+}
+
+bool PythonServer::isError() const
+{
+    return m_error;
 }
 
 
