@@ -20,29 +20,30 @@
 
 #ifndef _PYTHONSERVER_H
 #define _PYTHONSERVER_H
-#include <QObject>
-#include <QString>
+#include <string>
 
 struct _object;
 using PyObject = _object;
 
-class PythonServer : public QObject
+class PythonServer
 {
-  Q_OBJECT
   public:
-    explicit PythonServer(QObject* parent = nullptr);
+    explicit PythonServer() = default;
 
-  public Q_SLOTS:
-    Q_SCRIPTABLE void login();
-    Q_SCRIPTABLE void setFilePath(const QString& path);
-    Q_SCRIPTABLE void runPythonCommand(const QString& command) const;
-    Q_SCRIPTABLE QString getOutput() const;
-    Q_SCRIPTABLE QString getError() const;
-    Q_SCRIPTABLE QString variables(bool parseValue) const;
+  public:
+    void login();
+    void interrupt();
+    void setFilePath(const std::string& path, const std::string& dir);
+    void runPythonCommand(const std::string& command);
+    std::string getOutput() const;
+    std::string getError() const;
+    bool isError() const;
+    std::string variables(bool parseValue) const;
 
   private:
-    PyObject* m_pModule;
-    QString filePath;
+    PyObject* m_pModule{nullptr};
+    bool m_error{false};
+    std::string filePath;
 };
 
 #endif
