@@ -76,7 +76,7 @@ QString QalculateVariableManagementExtension::loadVariables(const QString& fileN
 }
 
 // Custom Plot Extension. This extension does not fit into the normal pattern,
-// because it inherts Cantor::Extension directly.
+// because it inherits Cantor::Extension directly.
 // Also it does not do anything at all, because all the work is done by the
 // QalculatePlotAssistant
 QalculatePlotExtension::QalculatePlotExtension(QObject* parent) :
@@ -84,9 +84,7 @@ QalculatePlotExtension::QalculatePlotExtension(QObject* parent) :
 {
 }
 
-QalculatePlotExtension::~QalculatePlotExtension()
-{
-}
+QalculatePlotExtension::~QalculatePlotExtension() = default;
 
 QString QalculateCASExtension::solve(const QStringList& equations, const QStringList& variables)
 {
