@@ -27,10 +27,10 @@ class SageExpression : public Cantor::Expression
 {
   Q_OBJECT
   public:
-    SageExpression(Cantor::Session*);
+    explicit SageExpression(Cantor::Session*, bool internal = false);
 
-    void evaluate() Q_DECL_OVERRIDE;
-    void interrupt() Q_DECL_OVERRIDE;
+    void evaluate() override;
+    void interrupt() override;
 
     void parseOutput(const QString&);
     void parseError(const QString&);
@@ -43,13 +43,14 @@ class SageExpression : public Cantor::Expression
     void evalFinished();
 
   protected:
-    QString additionalLatexHeaders() Q_DECL_OVERRIDE;
+    QString additionalLatexHeaders() override;
 
   private:
     QString m_outputCache;
     QString m_imagePath;
     bool m_isHelpRequest;
     int m_promptCount;
+    bool m_syntaxError;
 };
 
 #endif /* _SAGEEXPRESSION_H */
