@@ -33,8 +33,8 @@
 class SageHighlighter : public Cantor::DefaultHighlighter
 {
   public:
-    SageHighlighter( QObject* parent);
-    ~SageHighlighter() override;
+    explicit SageHighlighter( QObject* parent);
+    ~SageHighlighter() override = default;
 };
 
 #endif /* _SAGEHIGHLIGHTER_H */
