@@ -22,24 +22,22 @@
 #define _SCILABHIGHLIGHTER_H
 
 #include "defaulthighlighter.h"
+#include "scilabexpression.h"
 
 class ScilabHighlighter : public Cantor::DefaultHighlighter
 {
     Q_OBJECT
 
     public:
-        ScilabHighlighter(QObject* parent);
-        ~ScilabHighlighter() override;
-
-    public Q_SLOTS:
-        void updateHighlight();
-        void addVariableHighlight();
+        ScilabHighlighter(QObject* parent, Cantor::Session* session);
+        ~ScilabHighlighter() override = default;
 
     protected:
-        void highlightBlock(const QString &text) Q_DECL_OVERRIDE;
-        QString nonSeparatingCharacters() const Q_DECL_OVERRIDE;
+        void highlightBlock(const QString&) override;
+        QString nonSeparatingCharacters() const override;
 
     private:
+        Cantor::Session* m_session;
         QRegExp commentStartExpression;
         QRegExp commentEndExpression;
 };
