@@ -53,7 +53,7 @@ class ScilabSession : public Cantor::Session
         Cantor::Expression* evaluateExpression(const QString& command, Cantor::Expression::FinishingBehavior behave = Cantor::Expression::FinishingBehavior::DoNotDelete, bool internal = false) override;
         Cantor::CompletionObject* completionFor(const QString& command, int index=-1) override;
         void runFirstExpression() override;
-        QAbstractItemModel* variableModel() override;
+        Cantor::DefaultVariableModel* variableModel() const override;
 
     public Q_SLOTS:
         void readOutput();
