@@ -83,6 +83,7 @@ class CANTOR_EXPORT Backend : public QObject, public KXMLGUIClient
      * Destructor. Doesn't anything.
      */
     ~Backend() override;
+
   public:
 
     /**
@@ -103,7 +104,7 @@ class CANTOR_EXPORT Backend : public QObject, public KXMLGUIClient
      * @return @c false some requirements are missing. e.g. the maxima executable can not be found
      * @see Capability
     */
-    virtual bool requirementsFullfilled(QString* const reason = nullptr) const;
+    virtual bool requirementsFullfilled(QString* const reason = nullptr) const = 0;
 
     /**
      * Returns a unique string to identify this backend.
@@ -116,7 +117,7 @@ class CANTOR_EXPORT Backend : public QObject, public KXMLGUIClient
      * Returns the recommended version of the backend supported by Cantor
      * @return the recommended version of the backend
      */
-    virtual QString version() const;
+    virtual QString version() const = 0;
 
     //Stuff extracted from the .desktop file
     /**
@@ -143,16 +144,16 @@ class CANTOR_EXPORT Backend : public QObject, public KXMLGUIClient
     /**
      * Returns an Url pointing to the Help of the Backend
      * The method should be overwritten by all Backends(who have an online help)
-     * You should make the returned Url translateble, e.g. by doing something like:
+     * You should make the returned Url translatable, e.g. by doing something like:
      * return i18nc("the url to the documentation of KAlgebra, please check if there is a translated version and use the correct url",
-     *   "http://docs.kde.org/stable/en/kdeedu/kalgebra/");
+     *   "https://docs.kde.org/stable5/en/kdeedu/kalgebra/index.html");
      * @return Url of the help
      */
-    virtual QUrl helpUrl() const;
+    virtual QUrl helpUrl() const = 0;
     /**
      * Returns if the backend should be enabled (shown in the Backend dialog)
      * @return @c true, if the enabled flag is set to true, and the requirements are fulfilled
-     * @return @c false, if the backend was purposly disabled, or requirements are missing
+     * @return @c false, if the backend was purposely disabled, or requirements are missing
      * @see requirementsFullfilled()
      */
     bool isEnabled() const;
@@ -172,13 +173,13 @@ class CANTOR_EXPORT Backend : public QObject, public KXMLGUIClient
      * Returns a Widget for configuring this backend
      * @return Widget for usage in the Settings dialog
      */
-    virtual QWidget* settingsWidget(QWidget* parent) const;
+    virtual QWidget* settingsWidget(QWidget* parent) const = 0;
     /**
      * Returns a KConfig object, containing all the settings,
      * the backend might need
      * @return a KConfigSkeleton object, for configuring this backend
      */
-    virtual KConfigSkeleton* config() const;
+    virtual KConfigSkeleton* config() const = 0;
     /**
      * Returns a list of the names of all the Extensions supported by this backend
      * @return a list of the names of all the Extensions supported by this backend
@@ -190,7 +191,7 @@ class CANTOR_EXPORT Backend : public QObject, public KXMLGUIClient
      * if the Backend doesn't have an extension with this name.
      * @return Pointer to the Extension object with the given name
      */
-    Extension * extension(const QString& name) const;
+    Extension* extension(const QString& name) const;
 
     /**
      * Returns a list of the names of all the installed and enabled backends
@@ -208,6 +209,14 @@ class CANTOR_EXPORT Backend : public QObject, public KXMLGUIClient
      * @return the backend with the given name, or null if it isn't found
      */
     static Backend* getBackend(const QString& name);
+
+    /**
+     * @return @c true if all the requirements (the path is correct, the file is executable, etc.) are fulfilled
+     * for the backend @c Name with the path to the executable @c path and false otherwise.
+     * In case the requrements are not fulfilled, the reason is written to @c reason.
+     */
+    static bool checkExecutable(const QString& name, const QString& path, QString* reason);
+
   private:
     BackendPrivate* d;
 };
