@@ -21,7 +21,7 @@
 #ifndef DEFAULTHIGHLIGHTER_H
 #define DEFAULTHIGHLIGHTER_H
 
-#include <cantor_export.h>
+#include "cantor_export.h"
 
 #include <QSyntaxHighlighter>
 
@@ -30,6 +30,7 @@ class QGraphicsTextItem;
 namespace Cantor
 {
 class DefaultHighlighterPrivate;
+class Session;
 
 /**
  * The DefaultHighlighter is an implementation QSyntaxHighlighter.
@@ -49,7 +50,8 @@ class CANTOR_EXPORT DefaultHighlighter : public QSyntaxHighlighter
   Q_OBJECT
   public:
     explicit DefaultHighlighter(QObject* parent);
-    ~DefaultHighlighter() override;
+    explicit DefaultHighlighter(QObject* parent, Session* session);
+    virtual ~DefaultHighlighter() override;
 
     /**
      * Change the item being highlighted.
@@ -62,6 +64,25 @@ class CANTOR_EXPORT DefaultHighlighter : public QSyntaxHighlighter
      */
     void positionChanged(const QTextCursor&);
 
+  protected Q_SLOTS:
+    /**
+     * Convenience method, equivalent to @code addRules(functions, functionFormat()) @endcode
+     */
+    void addFunctions(const QStringList& functions);
+    /**
+     * Convenience method, equivalent to @code addRules(variables, variableFormat()) @endcode
+     */
+    void addVariables(const QStringList& variables);
+    /**
+     * Removes any rules previously added for the word @p word
+     */
+    void removeRule(const QString& word);
+    /**
+     * Convenience method, removes all rules with conditions from @p conditions
+     * @sa removeRule, addRules
+     */
+    void removeRules(const QStringList& conditions);
+
   protected:
     /**
      * This method is called by Cantor's KTextEdit and is where all the highlighting must take place.
@@ -121,32 +142,14 @@ class CANTOR_EXPORT DefaultHighlighter : public QSyntaxHighlighter
      * @param format the format used to display the matching parts of the text
      */
     void addRules(const QStringList& conditions, const QTextCharFormat& format);
-    /**
-     * Convenience method, equivalent to @code addRules(functions, functionFormat()) @endcode
-     */
-    void addFunctions(const QStringList& functions);
-    /**
-     * Convenience method, equivalent to @code addRules(variables, variableFormat()) @endcode
-     */
-    void addVariables(const QStringList& variables);
     /**
      * Convenience method, equivalent to @code addRules(keywords, keywordFormat()) @endcode
      */
     void addKeywords(const QStringList& keywords);
-
-    /**
-     * Removes any rules previously added for the word @p word
-     */
-    void removeRule(const QString& word);
     /**
      * Removes any rules previously added for the regular expression @p regexp
      */
     void removeRule(const QRegExp& regexp);
-    /**
-     * Convenience method, removes all rules with conditions from @p conditions
-     * @sa removeRule, addRules
-     */
-    void removeRules(const QStringList& conditions);
 
     /**
      * Highlight pairs added with addPair()
