@@ -18,6 +18,8 @@
     Copyright (C) 2009 Alexander Rieder <alexanderrieder@gmail.com>
  */
 
+#include <QJsonValue>
+
 #include "helpresult.h"
 using namespace Cantor;
 
@@ -45,6 +47,11 @@ HelpResult::HelpResult(const QString& text, bool isHtml) : d(new HelpResultPriva
     d->html = html;
 }
 
+Cantor::HelpResult::~HelpResult()
+{
+    delete d;
+}
+
 int HelpResult::type()
 {
     return HelpResult::Type;
@@ -58,6 +65,12 @@ QDomElement HelpResult::toXml(QDomDocument& doc)
     return e;
 }
 
+QJsonValue Cantor::HelpResult::toJupyterJson()
+{
+    // No need to save help result
+    return QJsonValue();
+}
+
 QString HelpResult::toHtml()
 {
     return d->html;
