@@ -23,11 +23,19 @@ using namespace Cantor;
 
 #include <QRegExp>
 #include <QUrl>
+#include <QJsonObject>
 
 class Cantor::ResultPrivate
 {
   public:
+    ~ResultPrivate()
+    {
+        if (jupyterMetadata)
+            delete jupyterMetadata;
+    }
 
+    QJsonObject* jupyterMetadata{nullptr};
+    int executionIndex{-1};
 };
 
 
@@ -62,4 +70,24 @@ void Result::saveAdditionalData(KZip* archive)
     //Do nothing
 }
 
+QJsonObject Cantor::Result::jupyterMetadata() const
+{
+    return d->jupyterMetadata ? *d->jupyterMetadata : QJsonObject();
+}
 
+void Cantor::Result::setJupyterMetadata(QJsonObject metadata)
+{
+    if (!d->jupyterMetadata)
+        d->jupyterMetadata = new QJsonObject();
+    *d->jupyterMetadata = metadata;
+}
+
+int Cantor::Result::executionIndex() const
+{
+    return d->executionIndex;
+}
+
+void Cantor::Result::setExecutionIndex(int index)
+{
+    d->executionIndex = index;
+}
