@@ -28,6 +28,7 @@
 #include <QBuffer>
 #include <KLocalizedString>
 #include <QDebug>
+#include <QKeyEvent>
 #include <QStandardPaths>
 #include <QDir>
 #include <QFileDialog>
@@ -467,6 +468,22 @@ bool MarkdownEntry::eventFilter(QObject* object, QEvent* event)
                 }
             }
         }
+        else if (event->type() == QEvent::KeyPress)
+        {
+            auto* key_event = static_cast<QKeyEvent*>(event);
+            if (key_event->matches(QKeySequence::Cancel))
+            {
+                setRenderedHtml(html);
+                for (auto iter = foundMath.begin(); iter != foundMath.end(); iter++)
+                    iter->second = false;
+                rendered = true;
+                markUpMath();
+                if (worksheet()->embeddedMathEnabled())
+                    renderMath();
+
+                return true;
+            }
+        }
     }
     return false;
 }
