@@ -23,9 +23,13 @@
 #include <QTextCursor>
 #include <QTextCharFormat>
 #include <QPalette>
+#include <QJsonValue>
+#include <QJsonObject>
 #include <KColorScheme>
 #include <KLocalizedString>
 
+#include "lib/jupyterutils.h"
+
 PageBreakEntry::PageBreakEntry(Worksheet* worksheet)
   : WorksheetEntry(worksheet)
 {
@@ -37,6 +41,7 @@ PageBreakEntry::PageBreakEntry(Worksheet* worksheet)
     cformat.setForeground(color.foreground(KColorScheme::InactiveText));
 
     cursor.insertText(i18n("--- Page Break ---"), cformat);
+    m_msgItem->setAlignment(Qt::AlignCenter);
 
     setFlag(QGraphicsItem::ItemIsFocusable);
 }
@@ -74,6 +79,35 @@ void PageBreakEntry::setContent(const QDomElement& content, const KZip& file)
     return;
 }
 
+void PageBreakEntry::setContentFromJupyter(const QJsonObject& cell)
+{
+    Q_UNUSED(cell);
+    return;
+}
+
+QJsonValue PageBreakEntry::toJupyterJson()
+{
+    QJsonObject root;
+
+    root.insert(QLatin1String("cell_type"), QLatin1String("raw"));
+    QJsonObject metadata;
+
+    // "raw_mimetype" vs "format"?
+    // See https://github.com/jupyter/notebook/issues/4730
+    // For safety set both keys
+    metadata.insert(QLatin1String("format"), QLatin1String("text/latex"));
+    metadata.insert(QLatin1String("raw_mimetype"), QLatin1String("text/latex"));
+
+    QJsonObject cantor;
+    cantor.insert(QLatin1String("from_page_break"), true);
+    metadata.insert(Cantor::JupyterUtils::cantorMetadataKey, cantor);
+
+    root.insert(Cantor::JupyterUtils::metadataKey, metadata);
+    Cantor::JupyterUtils::setSource(root, QLatin1String("\\pagebreak"));
+
+    return root;
+}
+
 QDomElement PageBreakEntry::toXml(QDomDocument& doc, KZip* archive)
 {
     Q_UNUSED(archive);
@@ -149,4 +183,14 @@ bool PageBreakEntry::wantFocus()
     return false;
 }
 
+bool PageBreakEntry::isConvertableToPageBreakEntry(const QJsonObject& cell)
+{
+    if (!Cantor::JupyterUtils::isRawCell(cell))
+        return false;
+
+    QJsonObject metadata = Cantor::JupyterUtils::getCantorMetadata(cell);
+    QJsonValue value = metadata.value(QLatin1String("from_page_break"));
+
+    return value.isBool() && value.toBool() == true;
+}
 
