@@ -37,8 +37,8 @@ class ScriptEditorWidget : public KXmlGuiWindow
   Q_OBJECT
   public:
     explicit ScriptEditorWidget( const QString& filter, const QString& highlightingMode, QWidget* parent = nullptr );
-    ~ScriptEditorWidget() override = default;
-    void open(QUrl url);
+    ~ScriptEditorWidget() override;
+    void open(const QUrl &url);
 
   Q_SIGNALS:
     void runScript(const QString& filename);
