@@ -24,7 +24,6 @@
 #include "resultitem.h"
 #include "worksheettextitem.h"
 #include "worksheetentry.h"
-#include "epsrenderer.h"
 
 #include "lib/latexresult.h"
 
@@ -42,15 +41,18 @@ class TextResultItem : public WorksheetTextItem, public ResultItem
     void update() override;
 
     void setLatex(Cantor::LatexResult* result);
+    QTextImageFormat toFormat(const QImage& image, const QString& latex);
 
     double width() const override;
     double height() const override;
 
     void deleteLater() override;
-    EpsRenderer* epsRenderer() const;
 
   protected Q_SLOTS:
     void toggleLatexCode();
+    void showHtml();
+    void showHtmlSource();
+    void showPlain();
     void saveResult();
 };
 
