@@ -108,6 +108,11 @@ Worksheet::~Worksheet()
     // while the scene is deleted. Maybe there is a better solution to
     // this problem, but I can't seem to find it.
     m_firstEntry = nullptr;
+
+    //disconnect from everything, no need to react on session status changes
+    //in the logout() when deleting the worksheet
+    disconnect(m_session, nullptr, nullptr, nullptr);
+
     if (m_session && m_session->status() != Cantor::Session::Disable)
         m_session->logout();
     if (m_session)
@@ -116,7 +121,6 @@ Worksheet::~Worksheet()
         if (m_session->status() != Cantor::Session::Disable)
             m_session->logout();
         m_session->deleteLater();
-        m_session = nullptr;
     }
     if (m_jupyterMetadata)
         delete m_jupyterMetadata;
