@@ -36,6 +36,8 @@
 #include <QMimeData>
 #include <QGraphicsProxyWidget>
 #include <QBitmap>
+#include <QJsonArray>
+#include <QJsonObject>
 
 #include <QIcon>
 #include <KLocalizedString>
@@ -61,6 +63,7 @@ WorksheetEntry::WorksheetEntry(Worksheet* worksheet) : QGraphicsObject()
     m_actionBar = nullptr;
     m_actionBarAnimation = nullptr;
     m_aboutToBeRemoved = false;
+    m_jupyterMetadata = nullptr;
     setAcceptHoverEvents(true);
     worksheet->addItem(this);
 }
@@ -76,6 +79,8 @@ WorksheetEntry::~WorksheetEntry()
         m_animation->animation->deleteLater();
         delete m_animation;
     }
+    if (m_jupyterMetadata)
+        delete m_jupyterMetadata;
 }
 
 int WorksheetEntry::type() const
@@ -164,6 +169,35 @@ void WorksheetEntry::insertPageBreakEntryBefore()
     worksheet()->insertPageBreakEntryBefore(this);
 }
 
+void WorksheetEntry::convertToCommandEntry()
+{
+    worksheet()->changeEntryType(this, CommandEntry::Type);
+}
+
+void WorksheetEntry::convertToTextEntry()
+{
+    worksheet()->changeEntryType(this, TextEntry::Type);
+}
+
+void WorksheetEntry::convertToMarkdownEntry()
+{
+    worksheet()->changeEntryType(this, MarkdownEntry::Type);
+}
+
+void WorksheetEntry::convertToLatexEntry()
+{
+    worksheet()->changeEntryType(this, LatexEntry::Type);
+}
+
+void WorksheetEntry::convertToImageEntry()
+{
+    worksheet()->changeEntryType(this, ImageEntry::Type);
+}
+
+void WorksheetEntry::converToPageBreakEntry()
+{
+    worksheet()->changeEntryType(this, PageBreakEntry::Type);
+}
 
 void WorksheetEntry::showCompletion()
 {
@@ -196,7 +230,7 @@ void WorksheetEntry::startDrag(QPointF grabPos)
 
     QDrag* drag = new QDrag(worksheetView());
     qDebug() << size();
-    const qreal scale = worksheet()->epsRenderer()->scale();
+    const qreal scale = worksheet()->renderer()->scale();
     QPixmap pixmap((size()*scale).toSize());
     pixmap.fill(QColor(255, 255, 255, 0));
     QPainter painter(&pixmap);
@@ -670,9 +704,7 @@ void WorksheetEntry::remove()
         worksheet()->setLastEntry(previous());
 
     // make the entry invisible to QGraphicsScene's itemAt() function
-    hide();
-    worksheet()->updateLayout();
-    deleteLater();
+    forceRemove();
 }
 
 void WorksheetEntry::setSize(QSizeF size)
@@ -811,3 +843,22 @@ bool WorksheetEntry::wantFocus()
 {
     return true;
 }
+
+QJsonObject WorksheetEntry::jupyterMetadata() const
+{
+    return m_jupyterMetadata ? *m_jupyterMetadata : QJsonObject();
+}
+
+void WorksheetEntry::setJupyterMetadata(QJsonObject metadata)
+{
+    if (m_jupyterMetadata == nullptr)
+        m_jupyterMetadata = new QJsonObject();
+    *m_jupyterMetadata = metadata;
+}
+
+void WorksheetEntry::forceRemove()
+{
+    hide();
+    worksheet()->updateLayout();
+    deleteLater();
+}
