@@ -33,13 +33,12 @@ WorksheetImageItem::WorksheetImageItem(QGraphicsObject* parent)
 {
     connect(this, SIGNAL(menuCreated(QMenu*,QPointF)), parent,
             SLOT(populateMenu(QMenu*,QPointF)), Qt::DirectConnection);
-    m_maxWidth = 0;
 }
 
 WorksheetImageItem::~WorksheetImageItem()
 {
-    if (worksheet() && m_maxWidth > 0 && width() > m_maxWidth)
-        worksheet()->removeProtrusion(width() - m_maxWidth);
+    if (worksheet())
+        worksheet()->removeRequestedWidth(this);
 }
 
 int WorksheetImageItem::type() const
@@ -58,12 +57,8 @@ qreal WorksheetImageItem::setGeometry(qreal x, qreal y, qreal w, bool centered)
         setPos(x + w/2 - width()/2, y);
     } else {
         setPos(x, y);
-        if (m_maxWidth < width())
-            worksheet()->updateProtrusion(width() - m_maxWidth, width() - w);
-        else
-            worksheet()->addProtrusion(width() - w);
     }
-    m_maxWidth = w;
+    worksheet()->setRequestedWidth(this, scenePos().x() + width());
 
     return height();
 }
@@ -85,18 +80,10 @@ QSizeF WorksheetImageItem::size()
 
 void WorksheetImageItem::setSize(QSizeF size)
 {
-    qreal oldProtrusion = x() + m_size.width() - m_maxWidth;
-    qreal newProtrusion = x() + size.width() - m_maxWidth;
-    if (oldProtrusion > 0) {
-        if (newProtrusion > 0)
-            worksheet()->updateProtrusion(oldProtrusion, newProtrusion);
-        else
-            worksheet()->removeProtrusion(oldProtrusion);
-    } else {
-        if (newProtrusion > 0)
-            worksheet()->addProtrusion(newProtrusion);
-    }
     m_size = size;
+
+    qreal width = scenePos().x() + size.width();
+    worksheet()->setRequestedWidth(this, width);
 }
 
 QSize WorksheetImageItem::imageSize()
@@ -123,7 +110,7 @@ void WorksheetImageItem::paint(QPainter *painter,
 
 void WorksheetImageItem::setEps(const QUrl& url)
 {
-    const QImage img = worksheet()->epsRenderer()->renderToImage(url, &m_size);
+    const QImage img = worksheet()->renderer()->renderToImage(url, Cantor::Renderer::EPS, &m_size);
     m_pixmap = QPixmap::fromImage(img.convertToFormat(QImage::Format_ARGB32));
 }
 
@@ -133,11 +120,22 @@ void WorksheetImageItem::setImage(QImage img)
     setSize(m_pixmap.size());
 }
 
+void WorksheetImageItem::setImage(QImage img, QSize displaySize)
+{
+    m_pixmap = QPixmap::fromImage(img);
+    setSize(displaySize);
+}
+
 void WorksheetImageItem::setPixmap(QPixmap pixmap)
 {
     m_pixmap = pixmap;
 }
 
+QPixmap WorksheetImageItem::pixmap() const
+{
+    return m_pixmap;
+}
+
 void WorksheetImageItem::populateMenu(QMenu* menu, QPointF pos)
 {
     emit menuCreated(menu, mapToParent(pos));
