@@ -32,8 +32,8 @@ WorksheetView::WorksheetView(Worksheet* scene, QWidget* parent) : QGraphicsView(
     m_vAnimation(nullptr),
     m_worksheet(scene)
 {
-    connect(scene, SIGNAL(sceneRectChanged(const QRectF&)),
-            this, SLOT(sceneRectChanged(const QRectF&)));
+    connect(scene, SIGNAL(sceneRectChanged(QRectF)),
+            this, SLOT(sceneRectChanged(QRectF)));
     setAlignment(Qt::AlignLeft | Qt::AlignTop);
     //setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
     setHorizontalScrollBarPolicy(Qt::ScrollBarAsNeeded);
@@ -276,3 +276,10 @@ void WorksheetView::zoomOut()
     scale(1/1.1, 1/1.1);
     updateSceneSize();
 }
+
+void WorksheetView::actualSize()
+{
+    scale (1/m_scale, 1/m_scale);
+    m_scale = 1.0;
+    updateSceneSize();
+}
